@@ -33,7 +33,7 @@ class TransactionPipeResultOptions(pydantic.BaseModel):
 class MessageTransaction(pydantic.BaseModel):
     fnc: Callable
     args: Optional[Dict]
-    pipe_result_options: Optional[TransactionPipeResultOptions]
+    pipe_result_options: Optional[Union, Callable]
 
 
 class MessagePipeline(pydantic.BaseModel):
@@ -68,11 +68,16 @@ class MessagePipeline(pydantic.BaseModel):
                         message = tx.fnc(message, self.logger, **kwargs)
 
                 if tx.pipe_result_options:
-                    if tx.pipe_result_options.with_response_options:
-                        message = await self.pipe_event_with_response(message, emitter, message_key_as_event,
-                                                                      tx.pipe_result_options, **kwargs)
+                    if inspect.isfunction(tx.pipe_result_options):
+                        pipe_result_options: TransactionPipeResultOptions = tx.pipe_result_options(message, self.logger,
+                                                                                                   **kwargs)
                     else:
-                        self.pipe_event(message, emitter, message_key_as_event, tx.pipe_result_options, **kwargs)
+                        pipe_result_options: TransactionPipeResultOptions = tx.pipe_result_options
+                    if pipe_result_options.with_response_options:
+                        message = await self.pipe_event_with_response(message, emitter, message_key_as_event,
+                                                                      pipe_result_options, **kwargs)
+                    else:
+                        self.pipe_event(message, emitter, message_key_as_event, pipe_result_options, **kwargs)
         except Exception as e:
             self.logger.error(f'execute => Exception: '
                               f'type: {sys.exc_info()[0]}; '
